@@ -291,7 +291,7 @@ template<class charT> bool Fastcgipp::Http::Session<charT>::fill(const char* dat
 				const char* start=(char*)memchr(end, '=', valueSize-(end-data));
 				if(start)
 				{
-					boundarySize=valueSize-(++start-data);
+					boundarySize=valueSize-(++start-value);
 					boundary.reset(new char[boundarySize]);
 					memcpy(boundary.get(), start, boundarySize);
 				}
